pub struct CommonAttributes { /* private fields */ }Trait Implementations
Sourceimpl Clone for CommonAttributes
impl Clone for CommonAttributes
Sourcefn clone(&self) -> CommonAttributes
fn clone(&self) -> CommonAttributes
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommonAttributes
impl Debug for CommonAttributes
Sourceimpl Default for CommonAttributes
impl Default for CommonAttributes
Sourcefn default() -> CommonAttributes
fn default() -> CommonAttributes
Returns the “default value” for a type. Read more
Sourceimpl JsonSchema for CommonAttributes
impl JsonSchema for CommonAttributes
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CommonAttributes
impl PartialEq for CommonAttributes
Sourceimpl Serialize for CommonAttributes
impl Serialize for CommonAttributes
impl StructuralPartialEq for CommonAttributes