pub struct Document { /* private fields */ }Trait Implementations
Sourceimpl HasChildren<StructuralSubElement> for Document
impl HasChildren<StructuralSubElement> for Document
fn with_children(children: Vec<StructuralSubElement>) -> Document
fn children(&self) -> &Vec<StructuralSubElement>
fn children_mut(&mut self) -> &mut Vec<StructuralSubElement>
fn append_child<R: Into<C>>(&mut self, child: R)
fn append_children<R: Into<C> + Clone>(&mut self, more: &[R])
Sourceimpl JsonSchema for Document
impl JsonSchema for Document
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Document
impl RefUnwindSafe for Document
impl Send for Document
impl Sync for Document
impl Unpin for Document
impl UnwindSafe for Document